Crate groestlcoinconsensus

Crate groestlcoinconsensus 

Enums

Error

Constants

VERIFY_ALL
VERIFY_CHECKLOCKTIMEVERIFY
VERIFY_CHECKSEQUENCEVERIFY
VERIFY_DERSIG
VERIFY_NONE
VERIFY_NULLDUMMY
VERIFY_P2SH
VERIFY_WITNESS

Functions

bitcoinconsensus_verify_script_with_amount
bitcoinconsensus_version
height_to_flags
Compute flags for soft fork activation heights on the groestlcoin network
verify
Verify a single spend (input) of a Groestlcoin transaction.
verify_with_flags
Same as verify but with flags that turn past soft fork features on or off
version
Return libgroestlcoinconsenus version